@@ -3,11 +3,11 @@ package Org::Parser;
 use 5.010001;
 use Moo;
 
-use File::Slurp;
+use File::Slurp::Tiny qw(read_file);
 use Org::Document;
 use Scalar::Util qw(blessed);
 
-our $VERSION = '0.37'; # VERSION
+our $VERSION = '0.38'; # VERSION
 
 sub parse {
     my ($self, $arg, $opts) = @_;
@@ -71,14 +71,20 @@ sub parse_file {
 1;
 # ABSTRACT: Parse Org documents
 
+__END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 Org::Parser - Parse Org documents
 
+=head1 VERSION
+
+This document describes version 0.38 of Org::Parser (from Perl distribution Org-Parser), released on 2014-05-17.
+
 =head1 SYNOPSIS
 
  use 5.010;
@@ -233,8 +239,7 @@ Source repository is at L<https://github.com/sharyanto/perl-Org-Parser>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/Public/Dist/Display.html?Name=Org-Parser
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Org-Parser>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -246,14 +251,9 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-__END__
-
-
-1;
